==> ubo_app-0.7.3.tar.gz: ubo_app-0.7.3/ubo_app/services/0-ip/setup.py <==
# ruff: noqa: D100, D101, D102, D103, D104, D107, N999
from __future__ import annotations

import asyncio
import socket
from collections import defaultdict
from typing import cast

import psutil
from constants import INTERNET_STATE_ICON_ID, INTERNET_STATE_ICON_PRIORITY
from reducer import IPState
from ubo_gui.menu.types import ActionItem, HeadlessMenu, SubMenuItem

from ubo_app.store import autorun, dispatch
from ubo_app.store.app import RegisterSettingAppAction
from ubo_app.store.status_icons import StatusIconsRegisterAction
from ubo_app.utils.async_ import create_task


@autorun(lambda state: cast(IPState, getattr(state, 'ip', None)))
def get_ip_addresses(_: IPState) -> list[SubMenuItem]:
    ip_addresses_by_interface = defaultdict(list)
    for interface_name, interface_addresses in psutil.net_if_addrs().items():
        for address in interface_addresses:
            if address.family == socket.AddressFamily.AF_INET:
                ip_addresses_by_interface[interface_name].append(address.address)
    return [
        SubMenuItem(
            label=interface_name,
            icon='cable'
            if interface_name.startswith('eth')
            else 'wifi'
            if interface_name.startswith('wlan')
            else 'computer'
            if interface_name.startswith('lo')
            else 'network_node',
            sub_menu=HeadlessMenu(
                title=f'IP Addresses - {interface_name}',
                items=[
                    ActionItem(label=ip_address, icon='lan', action=print)
                    for ip_address in ip_addresses
                ],
            ),
        )
        for interface_name, ip_addresses in ip_addresses_by_interface.items()
    ]


def is_connected() -> bool:
    try:
        with socket.create_connection(('1.1.1.1', 53), timeout=2):
            return True
    except OSError:
        return False


async def check_connection() -> bool:
    while True:
        await asyncio.sleep(1)
        if is_connected():
            dispatch(
                StatusIconsRegisterAction(
                    icon='public',
                    priority=INTERNET_STATE_ICON_PRIORITY,
                    id=INTERNET_STATE_ICON_ID,
                ),
            )
        else:
            dispatch(
                StatusIconsRegisterAction(
                    icon='public_off',
                    priority=INTERNET_STATE_ICON_PRIORITY,
                    id=INTERNET_STATE_ICON_ID,
                ),
            )


create_task(check_connection())


IPMainMenu = SubMenuItem(
    label='IP Addresses',
    icon='lan',
    sub_menu=HeadlessMenu(
        title='WiFi Settings',
        items=get_ip_addresses,
    ),
)


def init_service() -> None:
    dispatch(
        [
            RegisterSettingAppAction(
                menu_item=IPMainMenu,
            ),
        ],
    )

==> ubo_app-0.7.4.tar.gz: ubo_app-0.7.4/ubo_app/services/0-ip/setup.py <==
# ruff: noqa: D100, D101, D102, D103, D104, D107, N999
from __future__ import annotations

import asyncio
import socket
from collections import defaultdict
from typing import Sequence

import psutil
from constants import INTERNET_STATE_ICON_ID, INTERNET_STATE_ICON_PRIORITY
from ubo_gui.menu.types import ActionItem, HeadlessMenu, SubMenuItem

from ubo_app.store import autorun, dispatch, subscribe_event
from ubo_app.store.app import RegisterSettingAppAction
from ubo_app.store.ip import IpNetworkInterface, IpUpdateAction, IpUpdateRequestEvent
from ubo_app.store.status_icons import StatusIconsRegisterAction
from ubo_app.utils.async_ import create_task


@autorun(lambda state: getattr(getattr(state, 'ip', None), 'interfaces', []))
def get_ip_addresses(interfaces: Sequence[IpNetworkInterface]) -> list[SubMenuItem]:
    if not interfaces:
        return []
    return [
        SubMenuItem(
            label=interface.name,
            icon='cable'
            if interface.name.startswith('eth')
            else 'wifi'
            if interface.name.startswith('wlan')
            else 'computer'
            if interface.name.startswith('lo')
            else 'network_node',
            sub_menu=HeadlessMenu(
                title=f'IP Addresses - {interface.name}',
                items=[
                    ActionItem(label=ip_address, icon='lan', action=print)
                    for ip_address in interface.ip_addresses
                ],
            ),
        )
        for interface in interfaces
    ]


def load_ip_addresses(_: IpUpdateRequestEvent | None = None) -> None:
    ip_addresses_by_interface = defaultdict(list)
    for interface_name, ip_addresses in psutil.net_if_addrs().items():
        for address in ip_addresses:
            if address.family == socket.AddressFamily.AF_INET:
                ip_addresses_by_interface[interface_name].append(address.address)

    dispatch(
        IpUpdateAction(
            interfaces=[
                IpNetworkInterface(name=interface_name, ip_addresses=ip_addresses)
                for interface_name, ip_addresses in ip_addresses_by_interface.items()
            ],
        ),
    )


def is_connected() -> bool:
    try:
        with socket.create_connection(('1.1.1.1', 53), timeout=2):
            return True
    except OSError:
        return False


async def check_connection() -> bool:
    while True:
        await asyncio.sleep(1)
        if is_connected():
            dispatch(
                StatusIconsRegisterAction(
                    icon='public',
                    priority=INTERNET_STATE_ICON_PRIORITY,
                    id=INTERNET_STATE_ICON_ID,
                ),
            )
        else:
            dispatch(
                StatusIconsRegisterAction(
                    icon='public_off',
                    priority=INTERNET_STATE_ICON_PRIORITY,
                    id=INTERNET_STATE_ICON_ID,
                ),
            )


IpMainMenu = SubMenuItem(
    label='IP Addresses',
    icon='lan',
    sub_menu=HeadlessMenu(
        title='WiFi Settings',
        items=get_ip_addresses,
    ),
)


def init_service() -> None:
    dispatch(
        [
            RegisterSettingAppAction(
                menu_item=IpMainMenu,
            ),
        ],
    )
    create_task(check_connection())

    subscribe_event(
        IpUpdateRequestEvent,
        load_ip_addresses,
    )
    load_ip_addresses()
